========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/oslo.config.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

==========================
Oslo Configuration Library
==========================

.. image:: https://img.shields.io/pypi/v/oslo.config.svg
    :target: https://pypi.org/project/oslo.config/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/dm/oslo.config.svg
    :target: https://pypi.org/project/oslo.config/
    :alt: Downloads

The Oslo configuration API supports parsing command line arguments and
.ini style configuration files.

* License: Apache License, Version 2.0
* Documentation: https://docs.openstack.org/oslo.config/latest/
* Source: https://git.openstack.org/cgit/openstack/oslo.config
* Bugs: https://bugs.launchpad.net/oslo.config
* Release notes:  https://docs.openstack.org/releasenotes/oslo.config/
